@@ -35,6 +35,7 @@ __all__ = (
     "SignInMethodType",
     "StatusType",
     "ServiceName",
+    "PaginatorName",
 )
 
 
@@ -355,3 +356,4 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+PaginatorName = Literal["list_backend_jobs"]
